@@ -1,8 +1,10 @@
+from textwrap import dedent
 import inspect
 import json
 import sys
 import os
 import functools
+import re  # Import re module
 import click
 import traceback  # Moved import to top
 from typing import Any, List, Dict, Optional, Callable, Union, get_origin, get_args, Literal
@@ -79,6 +81,14 @@ shared_options = [
         envvar="KARAKEEP_PYTHON_API_DISABLE_RESPONSE_VALIDATION",
         help="Disable Pydantic validation of API responses (returns raw data).",
     ),
+    click.option(
+        "--ascii",
+        "ensure_ascii", # Use 'ensure_ascii' as the destination variable name
+        is_flag=True,
+        default=False, # Default is False, meaning ensure_ascii=False by default
+        envvar="KARAKEEP_PYTHON_API_ENSURE_ASCII",
+        help="Escape non-ASCII characters in the JSON output (default: keep Unicode).",
+    ),
 ]
 
 
@@ -126,9 +136,9 @@ def print_openapi_spec(ctx, param, value):
     is_eager=True,  # Process this option before others
     help="Dump the OpenAPI specification JSON to stdout and exit.",
 )
-@add_options(shared_options)  # Apply shared options to the group
+@add_options(shared_options)  # Apply shared options to the group (ensure_ascii is now included)
 @click.pass_context
-def cli(ctx, base_url, api_key, verify_ssl, verbose, disable_response_validation):
+def cli(ctx, base_url, api_key, verify_ssl, verbose, disable_response_validation, ensure_ascii):
     """
     Karakeep Python API Command Line Interface.
 
@@ -162,6 +172,7 @@ def cli(ctx, base_url, api_key, verify_ssl, verbose, disable_response_validation
     ctx.obj["DISABLE_RESPONSE_VALIDATION"] = (
         disable_response_validation  # Store the flag
     )
+    ctx.obj["ENSURE_ASCII"] = ensure_ascii # Store the ensure_ascii flag
 
     # --- Configure Logger ---
     log_level = "DEBUG" if verbose else "INFO"
@@ -198,6 +209,7 @@ def create_click_command(
             verify_ssl = ctx.obj["VERIFY_SSL"]
             verbose = ctx.obj["VERBOSE"]
             disable_validation = ctx.obj["DISABLE_RESPONSE_VALIDATION"]  # Retrieve flag
+            ensure_ascii_output = ctx.obj["ENSURE_ASCII"] # Retrieve ensure_ascii flag
 
             if not api_key:
                 click.echo(
@@ -238,9 +250,32 @@ def create_click_command(
                     k: v for k, v in call_args.items() if k in valid_arg_names
                 }
 
-                # Note: No special '--data' handling needed anymore for create_a_new_bookmark
-                # Type conversion for basic types (str, int, bool) is handled by Click.
-                # List/Dict parameters still expect JSON strings if used elsewhere.
+                # --- JSON Parsing for Dict/List Parameters ---
+                # Iterate through the expected parameters from the signature
+                for param_name, param_sig in signature.parameters.items():
+                    if param_name in call_args:
+                        param_value = call_args[param_name]
+                        param_annotation = param_sig.annotation
+                        origin = getattr(param_annotation, "__origin__", None)
+
+                        # Check if the annotation is dict/list or typing.Dict/List
+                        # and if the received value is a string (needs parsing)
+                        if (
+                            (param_annotation in (dict, list) or origin in (dict, list, Dict, List))
+                            and isinstance(param_value, str)
+                        ):
+                            try:
+                                # Attempt to parse the JSON string
+                                call_args[param_name] = json.loads(param_value)
+                                logger.debug(f"Parsed JSON string for parameter '{param_name}'.")
+                            except json.JSONDecodeError as json_err:
+                                # Handle invalid JSON input from the user
+                                click.echo(
+                                    f"Error: Invalid JSON provided for parameter '{param_name.replace('_', '-')}': {json_err}",
+                                    err=True,
+                                )
+                                click.echo(f"Provided value: {param_value}", err=True)
+                                ctx.exit(1)
 
                 # Call the API method
                 try:
@@ -262,9 +297,10 @@ def create_click_command(
                 # Serialize and print the result
                 if result is not None:
                     output_data = serialize_output(result)
+                    # Use ensure_ascii_output flag to control JSON encoding
                     click.echo(
-                        json.dumps(output_data, indent=2)
-                    )  # Keep this for stdout result
+                        json.dumps(output_data, indent=2, ensure_ascii=ensure_ascii_output)
+                    )
                 else:
                     # Handle None result (e.g., 204 No Content) gracefully
                     # Verbose check is implicitly handled by logger level
@@ -302,35 +338,45 @@ def create_click_command(
     click_params = []
     # Use the docstring from the original method (captured by functools.update_wrapper)
     docstring = api_method.__doc__ or f"Execute the {api_method_name} API operation."
+    docstring = dedent(docstring)
     docstring_lines = docstring.split("\n")
-    help_text = docstring_lines[0].strip()  # First line as short help
-    full_help = docstring  # Full docstring as help
+    help_text = " ".join(docstring.split("\n\n")[0].splitlines()).strip()  # First lines as short help
+    # Full docstring as help
+    full_help = docstring
+
+    # tweak the whitespaces in the full help:
+    # full_help = full_help.replace("\n", "\n\n").replace("\n                ", " ")
+    full_help = full_help.replace("\n               ", " ")
+    full_help = full_help.replace("\n", "\n\n")
 
     # Extract parameter descriptions from the Args section of the docstring
     param_descriptions = {}
     in_args_section = False
     args_section_lines = []
+    assert "Returns:" in docstring
+    assert "Raises:" in docstring
     for line in docstring_lines:
-        stripped_line = line.strip()  # Corrected indentation
-        if stripped_line == "Args:":  # Corrected indentation
-            in_args_section = True  # Corrected indentation
+        stripped_line = line.strip()
+        if stripped_line == "Args:":
+            in_args_section = True
         elif (
             stripped_line == "Returns:" or stripped_line == "Raises:"
-        ):  # Corrected indentation
-            in_args_section = False  # Stop capturing when Returns/Raises section starts # Corrected indentation
-        elif in_args_section and stripped_line:  # Corrected indentation
-            args_section_lines.append(stripped_line)  # Corrected indentation
-            # Try parsing the parameter name and description
-            parts = stripped_line.split(":", 1)  # Corrected indentation
-            if len(parts) == 2:  # Corrected indentation
-                # Extract name, assuming format "name (type): description"
-                name_part = parts[0].split(" ")[0]  # Corrected indentation
-                # Clean potential trailing parenthesis from type hint parsing
-                name_part = name_part.rstrip(")")  # Corrected indentation
-                param_descriptions[name_part] = parts[
-                    1
-                ].strip()  # Corrected indentation
+        ):
+            in_args_section = False  # Stop capturing when Returns/Raises section starts
+        elif in_args_section and stripped_line:
+            args_section_lines.append(stripped_line)
+            # Use regex to capture 'param_name: description' structure, allowing leading whitespace
+            # Pattern: ^\s+ (parameter_name): \s* (description) $
+            match = re.match(r"^\s+([a-zA-Z_][a-zA-Z0-9_]*):\s+(.*)$", line)
+            if match and match.group(1) != "Example":
+                param_name = match.group(1)
+                description = match.group(2).strip()
+                param_descriptions[param_name] = description
+                logger.trace(f"Parsed docstring param: '{param_name}' -> '{description}'")
+            else:
+                param_descriptions[param_name] += " " + stripped_line
 
+    # Removed breakpoint() that was added for debugging
     # Add parameters from signature to Click command
     for param in params:  # Use the filtered list from signature inspection
         param_name_cli = param.name.replace("_", "-")  # Use kebab-case for CLI options
